@@ -8,4 +8,4 @@ from .number_series import NumberSeries
 from .receiver import Receiver
 from .sender import Sender
 from .enum_repeats_builder import EnumRepeatsBuilder
-from .error_message import ErrorMessage
+from .error_messages import ErrorMessages
