@@ -11,6 +11,7 @@ from coin_sdk.number_portability.messages.enum import EnumActivationNumberBuilde
     EnumProfileActivationBuilder, EnumProfileDeactivationBuilder
 from coin_sdk.number_portability.messages.enum.enum_activation_operator_builder import EnumActivationOperatorBuilder
 from coin_sdk.number_portability.messages.enum.enum_deactivation_operator_builder import EnumDeactivationOperatorBuilder
+from coin_sdk.number_portability.messages.portingrequest.porting_request_builder import ContractType
 from coin_sdk.number_portability.messages.tariffchangeservicenumber.tariff_change_service_number_builder import \
     TariffChangeServiceNumberBuilder
 from coin_sdk.number_portability.npconfig import NpConfig, set_logging
@@ -43,6 +44,7 @@ class ExamplesTest(unittest.TestCase):
             .set_dossierid(dossier_id)
             .set_recipientnetworkoperator('LOADB')
             .set_header(sender_network_operator='LOADA', receiver_network_operator='LOADB')
+            .set_contract(ContractType.CONTINUATION)
             .add_porting_request_seq()
                 .set_number_series('0612345678', '0612345678')
                 .finish()
@@ -54,7 +56,7 @@ class ExamplesTest(unittest.TestCase):
             .build()
         )
         result = sender.send_message(porting_request)
-        self.assertRegex(result[0], "[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{12}", "Should match the transactionId");
+        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");
 
     def test_cancel(self):
         dossier_id = self._generate_random_dossier_id('LOADA')
@@ -63,7 +65,7 @@ class ExamplesTest(unittest.TestCase):
             .set_header(sender_network_operator='LOADA', receiver_network_operator='LOADB') \
             .build()
         result = sender.send_message(cancel)
-        self.assertRegex(result[0], "[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{12}", "Should match the transactionId");
+        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");
 
     def test_deactivation(self):
         dossier_id = self._generate_random_dossier_id('LOADA')
@@ -79,7 +81,7 @@ class ExamplesTest(unittest.TestCase):
             .build()
         )
         result = sender.send_message(deactivation)
-        self.assertRegex(result[0], "[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{12}", "Should match the transactionId");
+        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");
 
     def test_porting_performed(self):
         dossier_id = self._generate_random_dossier_id('LOADA')
@@ -99,7 +101,7 @@ class ExamplesTest(unittest.TestCase):
             .build()
         )
         result = sender.send_message(porting_performed)
-        self.assertRegex(result[0], "[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{12}", "Should match the transactionId");
+        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");
 
     def test_porting_request_answer(self):
         dossier_id = self._generate_random_dossier_id('LOADA')
@@ -127,7 +129,7 @@ class ExamplesTest(unittest.TestCase):
             .build()
         )
         result = sender.send_message(porting_performed_answer)
-        self.assertRegex(result[0], "[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{12}", "Should match the transactionId");
+        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");
 
     def test_porting_request_answer_delayed(self):
         dossier_id = self._generate_random_dossier_id('LOADA')
@@ -139,7 +141,7 @@ class ExamplesTest(unittest.TestCase):
             .build()
         )
         result = sender.send_message(porting_request_answer_delayed)
-        self.assertRegex(result[0], "[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{12}", "Should match the transactionId");
+        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");
 
     def test_send_error(self):
         dossier_id = self._generate_random_dossier_id('LOADA')
@@ -172,7 +174,7 @@ class ExamplesTest(unittest.TestCase):
             .build()
         )
         result = sender.send_message(activationsn)
-        self.assertRegex(result[0], "[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{12}", "Should match the transactionId");
+        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");
 
     def test_deactivationsn(self):
         dossier_id = self._generate_random_dossier_id('LOADA')
@@ -189,7 +191,7 @@ class ExamplesTest(unittest.TestCase):
             .build()
         )
         result = sender.send_message(deactivationsn)
-        self.assertRegex(result[0], "[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{12}", "Should match the transactionId");
+        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");
 
     def test_tariffchangesn(self):
         dossier_id = self._generate_random_dossier_id('LOADA')
@@ -206,7 +208,7 @@ class ExamplesTest(unittest.TestCase):
             .build()
         )
         result = sender.send_message(tariffchangesn)
-        self.assertRegex(result[0], "[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{12}", "Should match the transactionId");
+        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");
 
     def test_enumactivationnumber(self):
         dossier_id = self._generate_random_dossier_id('LOADA')
@@ -223,7 +225,7 @@ class ExamplesTest(unittest.TestCase):
             .build()
         )
         result = sender.send_message(enumactivationnumber)
-        self.assertRegex(result[0], "[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{12}", "Should match the transactionId");
+        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");
 
     def test_enumdeactivationnumber(self):
         dossier_id = self._generate_random_dossier_id('LOADA')
@@ -240,7 +242,7 @@ class ExamplesTest(unittest.TestCase):
             .build()
         )
         result = sender.send_message(enumdeactivationnumber)
-        self.assertRegex(result[0], "[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{12}", "Should match the transactionId");
+        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");
 
     def test_enumactivationoperator(self):
         dossier_id = self._generate_random_dossier_id('LOADA')
@@ -257,7 +259,7 @@ class ExamplesTest(unittest.TestCase):
             .build()
         )
         result = sender.send_message(enumactivationoperator)
-        self.assertRegex(result[0], "[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{12}", "Should match the transactionId");
+        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");
 
     def test_enumdeactivationoperator(self):
         dossier_id = self._generate_random_dossier_id('LOADA')
@@ -274,7 +276,7 @@ class ExamplesTest(unittest.TestCase):
             .build()
         )
         result = sender.send_message(enumdeactivationoperator)
-        self.assertRegex(result[0], "[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{12}", "Should match the transactionId");
+        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");
 
     def test_enumprofileactivation(self):
         dossier_id = self._generate_random_dossier_id('LOADA')
@@ -305,7 +307,7 @@ class ExamplesTest(unittest.TestCase):
             .build()
         )
         result = sender.send_message(enumprofileactivation)
-        self.assertRegex(result[0], "[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{12}", "Should match the transactionId");
+        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");
 
     def test_enumprofiledeactivation(self):
         dossier_id = self._generate_random_dossier_id('LOADA')
@@ -319,7 +321,7 @@ class ExamplesTest(unittest.TestCase):
             .build()
         )
         result = sender.send_message(enumprofiledeactivation)
-        self.assertRegex(result[0], "[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{12}", "Should match the transactionId");
+        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");
 
     def test_receive_message(self):
         TestReceiver(config).start_stream(confirmation_status=ConfirmationStatus.ALL, offset_persister=TestOffsetPersister)
